跳到主要内容

WriteTraffic

结构体 WriteTraffic 

pub struct WriteTraffic<'c, Data> { /* private fields */ }
展开描述

允许加密应用数据

实现

Source

impl<Data> WriteTraffic<'_, Data>

pub fn encrypt( &mut self, application_data: &[u8], outgoing_tls: &mut [u8], ) -> Result<usize, EncryptError>

Encrypts application_data into the outgoing_tls 缓冲区

返回数量 bytes that were written into outgoing_tls, 或 an error if the provided 缓冲区 is too small. In the error case, outgoing_tls is not modified

pub fn queue_close_notify( &mut self, outgoing_tls: &mut [u8], ) -> Result<usize, EncryptError>

Encrypts 一个 close_notify warning alert in outgoing_tls

返回数量 bytes that were written into outgoing_tls, 或 an error if the provided 缓冲区 is too small. In the error case, outgoing_tls is not modified

pub fn refresh_traffic_keys(self) -> Result<(), Error>

Arranges 用于 一个 TLS 1.3 key_update 到 be sent.

This consumes the WriteTraffic state: 到 actually send the message, call UnbufferedConnectionCommon::process_tls_records again which will return 一个 ConnectionState::EncodeTlsData that emits the key_update message.

,请参见ConnectionCommon::refresh_traffic_keys() 用于 full documentation, including why you might call this 并 in what circumstances it will fail.

自动 Trait 实现



impl<'c, Data> Freeze for WriteTraffic<'c, Data>



impl<'c, Data> !RefUnwindSafe for WriteTraffic<'c, Data>



impl<'c, Data> Send for WriteTraffic<'c, Data>
where Data: Send,



impl<'c, Data> Sync for WriteTraffic<'c, Data>
where Data: Sync,



impl<'c, Data> Unpin for WriteTraffic<'c, Data>



impl<'c, Data> UnsafeUnpin for WriteTraffic<'c, Data>



impl<'c, Data> !UnwindSafe for WriteTraffic<'c, Data>

Blanket 实现

Source

impl<T> Any for T
where T: 'static + ?Sized,

Source

fn type_id(&self) -> TypeId

Gets the TypeId of self. 更多信息
Source

impl<T> Borrow<T> for T
where T: ?Sized,

Source

fn borrow(&self) -> &T

Immutably borrows 从 an owned value. 更多信息
Source

impl<T> BorrowMut<T> for T
where T: ?Sized,

Source

fn borrow_mut(&mut self) -> &mut T

Mutably borrows 从 an owned value. 更多信息
Source

impl<T> From<T> for T

Source

fn from(t: T) -> T

原样返回传入的参数。

Source

impl<T, U> Into<U> for T
where U: From<T>,

Source

fn into(self) -> U

Calls U::从(self)

That is, this conversion is whatever the implementation of From<T> 用于 U 的实现方式。

Source

impl<T, U> TryFrom<U> for T
where U: Into<T>,

Source

type Error = Infallible

转换出错时返回的类型。
Source

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
Source

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

Source

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
Source

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。